// ========================================================
/// @file       DK_PIC16_App.c
/// @brief      Function application function for RFDK_PIC16_LCD_ver1.0
/// @version    V1.0
/// @date       2013/06/17
/// @company    HOPE MICROELECTRONICS Co., Ltd.
/// @website    http://www.hoperf.com
/// @author     Geman Deng
/// @mobile     +86-013244720618
/// @tel        0755-82973805 Ext:846
// ========================================================
#include "DK_PIC16_App.h"

u8  gb_RxData[32];                                         //Receive data buffer
u8  gb_StatusTx=0;                                         //Tx status flag
u8  gb_StatusRx=0;                                         //Rx status flag
u8  gb_ErrorFlag=0;                                        //Error flag
u16 gw_TxLedTimer=0;                                       //Tx LED timer
u8  gb_TxLedCount=0;                                       //Tx LED count
u8  gb_SysTimer_1S=0;                                      //System timer for 1S

u8  gb_KeyDownFlag=0;                                      //Key down flag
u8  gb_KeyValue;                                           //Key value
u16 gw_KeyDebounceTimer=0;                                 //Debounce timer for key

u8  gb_BeepOnFlag=0;                                       //Buzzer on flag
u8  gb_BeepOnCount;                                        //Buzzer on count
u16 gw_ToneBuf[30];                                        //Tone cache
u8  gb_BeepTimerH;                                         //Timer reload value for buzzer
u8  gb_BeepTimerL;
u16 gw_BeepTimer;                                          //Buzzer timer

u16 gw_LCDFlashTimer=0;                                    //LCD flash display timer

u8  gb_SystemMode=0;                                       //System mode
u8  gb_SysMode_Set;                                        //System mode-Set mode
u16 gw_RF_SentInterval;                                    //Send interval
u16 gw_TxTimer=0;                                          //Send timer (time base 1S)
u8  gb_ModuleWorkEnableFlag=0;                             //Enable module work in Tx/Rx mode
u8  gb_ModuleWorkMode=0;                                   //Module work mode
u8  gb_RF_RSSI=0;                                          //RF RSSI signal
u8  gb_FirstPowerUpFlag=0;                                 //First power flag
u8  gb_ParameterChangeFlag=0;                              //Parameter change flag

u8  *RF_ModuleName;                                        //Module name cache
u16 *RF_FreqBuf;                                           //RF center frequency cache
u8  *RF_RateBuf;                                           //RF rate cache
u8  *RF_PowerBuf;                                          //RF power cache
u8  *RF_FdevBuf;                                           //RF deviation cache
u8  *RF_BandBuf;                                           //RF bandwidth cache
u8  *RF_RSSIBuf;                                           //RF RSSI cache
u8  gb_FreqBuf_Addr=0;                                     //RF center frequency cache address
u8  gb_RateBuf_Addr=0;
u8  gb_PowerBuf_Addr=0;
u8  gb_FdevBuf_Addr=0;
u8  gb_BandBuf_Addr=0;

u16 gw_SendDataCount=0;                                    //Send data count
u16 gw_ReceiveDataCount=0;                                 //Receive data count
/**********************************************************
**Name:     Delay_ms
**Function: Delay program
**Input:    time, Millisecond
**Output:   none
**********************************************************/
void Delay_ms(u32 time)
{
  u16 i;
  while(time--)
  {
    for(i = 0; i<333; i++)
    {
      ;
    } 
  }
}

/**********************************************************
**Name:     KeyRead
**Function: Get key value
**Input:    none
**Output:   temp, key value
**********************************************************/
u8 KeyRead(void)
{
  u8 temp=0;
  if(KEY1==0)
  {
    temp|=C_KeyDown;
  }
  if(KEY2==0)
  {
    temp|=C_KeyLeft;
  }
  if(KEY3==0)
  {
    temp|=C_KeyUp;
  }
  if(KEY4==0)
  {
    temp|=C_KeyRight;
  }
  return temp;
}

/**********************************************************
**Name:     KeyScan
**Function: Key scan
**Input:    none
**Output:   keyValue, key value
**********************************************************/
u8 KeyScan(void)
{
  u8 temp;
  u8 keyValue=0;
  temp=KeyRead();
  if(temp!=C_KeyNone)
  {
    if(gb_KeyDownFlag==0)
    {
      gw_KeyDebounceTimer=50;
      gb_KeyDownFlag=1;
      gb_KeyValue=temp;
    }
    else if(gw_KeyDebounceTimer==0 && gb_KeyValue==temp)
    {
      gb_KeyDownFlag=2;                                    //debounce
    }
  }
  else if(gb_KeyDownFlag==2)
  {
    keyValue=gb_KeyValue;                                  //release
    gb_KeyDownFlag=0;
  } 
  else
  {
    gb_KeyDownFlag=0;
  }
  return keyValue;
}

/**********************************************************
**Name:     TxLED_Deal
**Function: Tx LED display deal
**Input:    none
**Output:   none
**********************************************************/
void TxLED_Deal(void)
{
  if(gb_StatusTx==1)
  {
    if(gw_TxLedTimer==0)
    {
      gw_TxLedTimer=300;
      gb_TxLedCount++;
      if(gb_TxLedCount>6)
      {
        gb_TxLedCount=0;
      }
      
      switch(gb_TxLedCount)
      {
        case 1:
         LED4 = 1; break;
        case 2:
         LED3 = LED5 = 1; break;
        case 3: 
         LED1 = LED2 = LED6 = 1; break;
        case 4:
         LED4 = 0; break;
        case 5:
         LED3 = LED5 = 0; break;
        case 6:
         LED1 = LED2 = LED6 = 0; break;
        default:
         break;
      }
    }
  }
  else
  {       
    LED4=LED3=LED5=LED1=LED2=LED6=0;
    gb_TxLedCount=0;
  }
}

/**********************************************************
**Name:     RxLED_Deal
**Function: Rx LED display deal
**Input:    none
**Output:   none
**********************************************************/
void RxLED_Deal(void)
{
  if(gb_StatusRx==1)
  {
    LED7=1;
  }
  else
  {
    LED7=0;
  }
}

/**********************************************************
**Name:     SaveRFParameterToFlash
**Function: Save RF parameter to flash
**Input:    none
**Output:   none
**********************************************************/
void SaveRFParameterToFlash(void)
{
  u8 i;
  
  FlashErase(EEPROM_FirstAddr);
  gb_RxData[0]=0x5A;
  gb_RxData[1]=gb_FreqBuf_Addr;
  gb_RxData[2]=gb_RateBuf_Addr;
  gb_RxData[3]=gb_PowerBuf_Addr;
  gb_RxData[4]=gb_FdevBuf_Addr;
  gb_RxData[5]=gb_BandBuf_Addr; 
  gb_RxData[7]=gb_SystemMode;
  FlashWrite(EEPROM_FirstAddr, gb_RxData);
  for(i=0; i<32; i++)
    gb_RxData[i] = 0;
}

/**********************************************************
**Name:     InitSystemParameter
**Function: Initial system parameter
**Input:    none
**Output:   none
**********************************************************/
void InitSystemParameter(void)
{ 
  gw_SendDataCount=0;                                      //Send data count
  gw_ReceiveDataCount=0;                                   //Receive data count
  
  if(gb_FirstPowerUpFlag!=1)
  {
    gb_FreqBuf_Addr=0;
    gb_RateBuf_Addr=1;
    gb_PowerBuf_Addr=0;
    gb_FdevBuf_Addr=0;
    gb_BandBuf_Addr=0;
  }
  else
    gb_FirstPowerUpFlag=0;
  gw_RF_SentInterval=C_RF_SentInterval;                    //RF parameter Send interval time(ms)
      
  RF_ModuleName=(u8*)C_RFM69H_ModuleName;                  //RF module name 
  RF_FreqBuf=(u16*)C_RFM69H_FreqBuf;                       //RF parameter frequency
  RF_RateBuf=(u8*)C_RFM69H_RateBuf;                        //RF parameter data rate
  RF_PowerBuf=(u8*)C_RFM69H_PowerBuf;                      //RF parameter out power
  RF_FdevBuf=(u8*)C_RFM69H_FdevBuf;                        //RF parameter frequency devition
  RF_BandBuf=(u8*)C_RFM69H_BandBuf;                        //RF parameter band width
  RF_RSSIBuf=(u8*)C_RFM69H_RSSIBuf;                        //RF parameter RSSI
}

/**********************************************************
**Name:     DisplayRFParameter
**Function: Complex display RF parameter
**Input:    none
**Output:   none
**********************************************************/
void DisplayRFParameter(void)
{   
    if(gb_ErrorFlag!=1)
    {
      switch(gb_SystemMode)                                  //Flash Display
      {
        case C_SysMode_Set:
          SendStringToDispBuf(C_DispAddr_Time, (u8*)" set  ");
          gb_DispFlashFlag=C_FlashDisp_Time;
          break;
        case C_SysMode_NorTx:
          SendStringToDispBuf(C_DispAddr_Time, (u8*)" N--T ");                   
          break;
        case C_SysMode_TestTx:
          SendStringToDispBuf(C_DispAddr_Time, (u8*)" T--T ");                  
          break;
        case C_SysMode_NorRx:
          SendStringToDispBuf(C_DispAddr_Time, (u8*)" N--R ");                   
          break;
        case C_SysMode_TestRx:
          SendStringToDispBuf(C_DispAddr_Time, (u8*)" T--R ");                   
          break;
        case C_SysMode_ModuleSel:
          SendStringToDispBuf(C_DispAddr_Time, (u8*)"sel-RF");
          gb_DispFlashFlag=C_FlashDisp_RFM;                               
          break;
        case C_SysMode_EntrySet:        
          SendStringToDispBuf(C_DispAddr_Time, (u8*)" set  ");
          if(gb_SysMode_Set==C_SysMode_Set_Freq){gb_DispFlashFlag=C_FlashDisp_Freq;}
          else if(gb_SysMode_Set==C_SysMode_Set_Power){gb_DispFlashFlag=C_FlashDisp_PWR;}
          else if(gb_SysMode_Set==C_SysMode_Set_Rate){gb_DispFlashFlag=C_FlashDisp_BR;}       
          break;
      }
    }
    else
    {
      SendStringToDispBuf(C_DispAddr_Time, (u8*)" Err  "); //Error display
      gb_DispFlashFlag=C_FlashDisp_Time;
      BeepOn((u16*)MusicTab_Error);
    }
    
    DispSeg_HopeRF=1;
    SendStringToDispBuf(C_DispAddr_RFM, RF_ModuleName);DispSeg_RFM=1;    //Module name display
    switch(RF_FreqBuf[gb_FreqBuf_Addr])                    //Frequency display
    {
      case 315:
        DispSeg_315=1;DispSeg_434=0;DispSeg_868=0;DispSeg_915=0;
        break;
      case 434:
        DispSeg_315=0;DispSeg_434=1;DispSeg_868=0;DispSeg_915=0;
        break;
      case 868:
        DispSeg_315=0;DispSeg_434=0;DispSeg_868=1;DispSeg_915=0;
        break;
      case 915:
        DispSeg_315=0;DispSeg_434=0;DispSeg_868=0;DispSeg_915=1;
        break;
    }   
    SendNumberToDispBuf(C_DispAddr_BR,RF_RateBuf[gb_RateBuf_Addr]);DispSeg_P6=1;DispSeg_BR=1;     //RF Rate display
    
    if(RF_FdevBuf[0]==0)                                   //Receiver module
    {
      SendStringToDispBuf(C_DispAddr_Tx,(u8*)"    ");DispSeg_Tx=0;  
      SendNumberToDispBuf(C_DispAddr_Rx,gw_ReceiveDataCount);DispSeg_Rx=1;
      SendStringToDispBuf(C_DispAddr_PWR,(u8*)"  ");DispSeg_PWR=0; 
      SendStringToDispBuf(C_DispAddr_Fdev,(u8*)"   ");DispSeg_Fdev=0;     
      SendNumberToDispBuf(C_DispAddr_BW,RF_BandBuf[gb_BandBuf_Addr]);DispSeg_BW=1;
    }
    else if(RF_BandBuf[0]==0)                              //Transmitter module
    {     
      SendNumberToDispBuf(C_DispAddr_Tx,gw_SendDataCount);DispSeg_Tx=1; 
      SendStringToDispBuf(C_DispAddr_Rx,(u8*)"    ");DispSeg_Rx=0;
      SendNumberToDispBuf(C_DispAddr_PWR,RF_PowerBuf[gb_PowerBuf_Addr]);DispSeg_PWR=1;  
      SendNumberToDispBuf(C_DispAddr_Fdev,RF_FdevBuf[gb_FdevBuf_Addr]);DispSeg_Fdev=1;
      SendStringToDispBuf(C_DispAddr_BW,(u8*)"   ");DispSeg_BW=0;
    }
    else                                                   //Transceiver module                                                     
    {
      SendNumberToDispBuf(C_DispAddr_Tx,gw_SendDataCount);DispSeg_Tx=1; 
      SendNumberToDispBuf(C_DispAddr_Rx,gw_ReceiveDataCount);DispSeg_Rx=1;
      SendNumberToDispBuf(C_DispAddr_PWR,RF_PowerBuf[gb_PowerBuf_Addr]);DispSeg_PWR=1;   //RF out power display
      SendNumberToDispBuf(C_DispAddr_Fdev,RF_FdevBuf[gb_FdevBuf_Addr]);DispSeg_Fdev=1;        //RF Fdev display 
      SendNumberToDispBuf(C_DispAddr_BW,RF_BandBuf[gb_BandBuf_Addr]);DispSeg_BW=1;     //RF BW display
    }
    
    if(RF_RSSIBuf[0]!=0 &&(gb_SystemMode==C_SysMode_NorRx||gb_SystemMode==C_SysMode_TestRx))
    {
      DispSeg_Q5=1;                                        //RF RSSI signal display
      if(gb_RF_RSSI!=0xff)
      {
        DispSeg_Q4=1;
        DispSeg_Q3=1;
        DispSeg_Q2=1;
        DispSeg_Q1=1;
        if(gb_RF_RSSI<RF_RSSIBuf[3]){DispSeg_Q1=0;}
        if(gb_RF_RSSI<RF_RSSIBuf[2]){DispSeg_Q2=0;}
        if(gb_RF_RSSI<RF_RSSIBuf[1]){DispSeg_Q3=0;}
        if(gb_RF_RSSI<RF_RSSIBuf[0]){DispSeg_Q4=0;}  
      }
    }
    else                                                   //Transmitter module
    {
      DispSeg_Q5=0;DispSeg_Q4=0;DispSeg_Q3=0;DispSeg_Q2=0;DispSeg_Q1=0;
    }
}

/**********************************************************
**Name:     ModuleSelectModeEntryCheck
**Function: Confirm whether you can enter module select mode
**Input:    none
**Output:   none
**********************************************************/
void ModuleSelectModeEntryCheck(void)
{
  gb_FirstPowerUpFlag=1;                                   //FirstPowerUp
   
  FlashRead(EEPROM_FirstAddr, gb_RxData);
  if(gb_RxData[0]==0x5A)
  {   
    gb_FreqBuf_Addr=gb_RxData[1];
    gb_RateBuf_Addr=gb_RxData[2];
    gb_PowerBuf_Addr=gb_RxData[3];
    gb_FdevBuf_Addr=gb_RxData[4];
    gb_BandBuf_Addr=gb_RxData[5];
    
    gb_SystemMode=gb_RxData[7];
  }
  else
  {
    gb_FreqBuf_Addr=0;
    gb_RateBuf_Addr=1;
    gb_PowerBuf_Addr=0;
    gb_FdevBuf_Addr=0;
    gb_BandBuf_Addr=0;

    gb_SystemMode=C_SysMode_Set;                           //RF set mode
  } 

  if(gb_SystemMode==C_SysMode_NorTx || gb_SystemMode==C_SysMode_TestTx || gb_SystemMode==C_SysMode_NorRx || gb_SystemMode==C_SysMode_TestRx)
  {   
    gb_ModuleWorkEnableFlag=1;                             //Enable module work in Tx/Rx mode
    gb_ModuleWorkMode=C_ModuleWorkMode_Normal;             //Module entry normal mode  
    gb_ParameterChangeFlag=1;   
  }
  else
  {
    if(gb_SystemMode==C_SysMode_EntrySet)
    {
      gb_SysMode_Set=C_SysMode_Set_Freq;
    }
    gb_ModuleWorkEnableFlag=0;                             //Disable module work in Tx/Rx mode
    gb_ModuleWorkMode=C_ModuleWorkMode_Standby;            //Module entry stanby mode 
    gb_ParameterChangeFlag=2;  
  }
  
  InitSystemParameter();
}

/**********************************************************
**Name:     RFParameterSelect
**Function: Select RF parameter
**Input:    KeyValue, key value
**Output:   none
**********************************************************/
void RFParameterSelect(u8 KeyValue)
{ 
  if(KeyValue==C_KeyUp)                                    //Page Up key
  {
    BeepOn((u16*)MusicTab_KeySet);
    
    gb_SysMode_Set++;
    if(gb_SysMode_Set>C_SysMode_Set_Rate){gb_SysMode_Set=C_SysMode_Set_Freq;}   
    if(RF_FdevBuf[0]==0 && gb_SysMode_Set==C_SysMode_Set_Power){gb_SysMode_Set++;}
  }
  else if(KeyValue==C_KeyLeft)                             //Page left key
  {
    BeepOn((u16*)MusicTab_KeyMove);                        //buzzer on    
    
    switch(gb_SysMode_Set)
    {
      case C_SysMode_Set_Freq:
        if(gb_FreqBuf_Addr){gb_FreqBuf_Addr--;}
        else
        {
          while(1)
          {
            gb_FreqBuf_Addr++;
            if(RF_FreqBuf[gb_FreqBuf_Addr]==0)
            {
              gb_FreqBuf_Addr--;
              break;
            }
          }
        }
        break;
      case C_SysMode_Set_Power:        
        gb_PowerBuf_Addr++;
        if(RF_PowerBuf[gb_PowerBuf_Addr]==0){gb_PowerBuf_Addr=0;}
        break;
      case C_SysMode_Set_Rate:
        if(gb_RateBuf_Addr){gb_RateBuf_Addr--;}
        else
        {
          while(1)
          {
            gb_RateBuf_Addr++;
            if(RF_RateBuf[gb_RateBuf_Addr]==0)
            {
              gb_RateBuf_Addr--;
              break;
            }
          }
        }
        break;
    }         
  }
  else if(KeyValue==C_KeyRight)                            //Page right key
  {
    BeepOn((u16*)MusicTab_KeyMove);                        //buzzer on
    
    switch(gb_SysMode_Set)
    {
      case C_SysMode_Set_Freq:
        gb_FreqBuf_Addr++;
        if(RF_FreqBuf[gb_FreqBuf_Addr]==0){gb_FreqBuf_Addr=0;}
        break;
      case C_SysMode_Set_Power:
        if(gb_PowerBuf_Addr){gb_PowerBuf_Addr--;}
        else
        {
          while(1)
          {
            gb_PowerBuf_Addr++;
            if(RF_PowerBuf[gb_PowerBuf_Addr]==0)
            {
              gb_PowerBuf_Addr--;
              break;
            }
          }
        }        
        break;
      case C_SysMode_Set_Rate:
        gb_RateBuf_Addr++;
        if(RF_RateBuf[gb_RateBuf_Addr]==0){gb_RateBuf_Addr=0;}
        break;
    }
  }
  else if(KeyValue==C_KeyDown)                             //OK key
  {
    BeepOn((u16*)MusicTab_KeyOK);                          //Set over,  Quit set mode 
    
    gb_SystemMode=C_SysMode_Set;                           //Set mode
    SaveRFParameterToFlash(); 
  } 
}

/**********************************************************
**Name:     WorkModeSelect
**Function: Select work mode
**Input:    KeyValue, key value
**Output:   none
**********************************************************/
void WorkModeSelect(u8 KeyValue)
{   
  if(KeyValue==C_KeyUp)                                    //Page Up key
  { 
    gb_ErrorFlag=0;                                        //Clear error flag    
    gb_ParameterChangeFlag=2;
    gb_ModuleWorkMode=C_ModuleWorkMode_Standby;            //Module entry stanby mode
    
    BeepOn((u16*)MusicTab_KeySet);
    
    if(gb_SystemMode!=C_SysMode_Set)
    {
      gb_SystemMode=C_SysMode_Set;
    }
    else
    {       
      gb_SystemMode=C_SysMode_EntrySet; 
      gb_SysMode_Set=C_SysMode_Set_Freq;
    }
    SaveRFParameterToFlash();  }
  else if(KeyValue==C_KeyLeft && gb_ModuleWorkMode!=C_ModuleWorkMode_Normal)    //Page left key
  {
    BeepOn((u16*)MusicTab_KeyMove);                        //buzzer on  
      
    if(gb_SystemMode==C_SysMode_Set){gb_SystemMode=C_SysMode_TestRx+1;}
    gb_SystemMode--;
    if(RF_FdevBuf[0]==0 && gb_SystemMode==C_SysMode_TestTx){gb_SystemMode=C_SysMode_Set;}
    if(RF_BandBuf[0]==0 && gb_SystemMode==C_SysMode_TestRx){gb_SystemMode=C_SysMode_TestTx;}
  }
  else if(KeyValue==C_KeyRight && gb_ModuleWorkMode!=C_ModuleWorkMode_Normal)    //Page right key
  {
    BeepOn((u16*)MusicTab_KeyMove);                        //buzzer on
          
    gb_SystemMode++;
    if(gb_SystemMode>C_SysMode_TestRx){gb_SystemMode=C_SysMode_Set;}  
    if(RF_FdevBuf[0]==0 && gb_SystemMode==C_SysMode_NorTx){gb_SystemMode=C_SysMode_NorRx;}
    if(RF_BandBuf[0]==0 && gb_SystemMode==C_SysMode_NorRx){gb_SystemMode=C_SysMode_Set;}    
  }
  else if(KeyValue==C_KeyDown && gb_SystemMode!=C_SysMode_Set && gb_ModuleWorkMode!=C_ModuleWorkMode_Normal)    //OK key
  {
    BeepOn((u16*)MusicTab_KeyOver);                        //Set over,  Quit set mode 
  
    gb_DispFlashFlag=C_FlashDisp_None;                     //Close flash display flag 
    
    if(gb_ParameterChangeFlag==2){gb_ParameterChangeFlag=1;}   //Module parameter changed
    gb_ModuleWorkEnableFlag=1;                             //Enable module work in Tx/Rx mode
    gb_ModuleWorkMode=C_ModuleWorkMode_Normal;             //Module entry normal mode
    
    gw_SendDataCount=0;                                    //Send data count
    gw_ReceiveDataCount=0;                                 //Receive data count     

    SaveRFParameterToFlash();
  }
  else if(KeyValue!=C_KeyNone)
  {
    BeepOn((u16*)MusicTab_KeyErr);
  } 
}

/**********************************************************
**Name:     MenuConfig
**Function: Menu config & display
**Input:    none
**Output:   none
**********************************************************/
void MenuConfig(void)
{
  u8 KeyValue=KeyScan();                                   //Get key value
  
  if(gb_SystemMode==C_SysMode_EntrySet)                    //Parameter select mode
  { 
    RFParameterSelect(KeyValue);
  }
  else
  {
    WorkModeSelect(KeyValue);                              //Work mode
  }
  DisplayRFParameter();
  LCD_Display();                                           //Display  
}

/**********************************************************
**Name:     BeepOn
**Function: Play audio from buzzer
**Input:    *Tone, tone and time buffer
**Output:   none
**********************************************************/
void BeepOn(u16 *Tone)
{
  u8 i=0;
  if(!gb_BeepOnFlag)
  {
    gb_BeepOnFlag = 1;
    gb_BeepOnCount=0;
      
    while(1)
    { 
      if(Tone[i+1]!=0)
      {
        gw_ToneBuf[i]=Tone[i];
        gw_ToneBuf[i+1]=Tone[i+1];  
        i+=2;   
      }
      else
      {
        gw_ToneBuf[i]=0;
        gw_ToneBuf[i+1]=0;  
        break;
      }
    }
    TMR1ON = 1;                                            //Open timer1
  }
}

/**********************************************************
**Name:     BeepOff
**Function: Close buzzer
**Input:    none
**Output:   none
**********************************************************/
void BeepOff(void)
{
  TMR1ON = 0;                                              //Close timer1
  gb_BeepOnFlag = 0;  
  gb_BeepOnCount=0;
  gw_BeepTimer=0;   
  Buzzer=0;
}

/**********************************************************
**Name:     PowerOnMusic
**Function: Power on music
**Input:    none
**Output:   none
**********************************************************/
void PowerOnMusic(void)
{
  BeepOn((u16*)MusicTab_PowerOn);                          //Power on music
  LCD_DisplayAll();                                        //display all LCD seg
  DispSeg_915=1;DispSeg_RFM=1;DispSeg_MHz=1;
  while(1)
  {
    if((gw_BeepTimer==0)&&(gw_ToneBuf[gb_BeepOnCount+1]==0))
      break;
    LCD_Display();                                          
  }
  DispSeg_915=0;DispSeg_RFM=0;DispSeg_MHz=0;
  Clr_LCD();                                               //Clear LCD display
}

